@@ -22,6 +22,10 @@
 
 #include <octave/oct.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 // A simplified version of the filter function for specific lengths of a and b
 // in the Galois field GF(2)
 Array<int>
@@ -29,7 +33,7 @@ filter_gf2 (const Array<int>& b, const Array<int>& a,
             const Array<int>& x, const int& n)
 {
 
-  int x_len = x.length ();
+  int x_len = x.numel ();
   Array<int> si (dim_vector (n, 1), 0);
   Array<int> y (dim_vector (x_len, 1), 0);
 
