@@ -2496,7 +2496,7 @@ m = 3; n = 2^m -1; k = 4; t = 1;\n\
 msg = randint (10, k);\n\
 code = bchenco (msg, n, k);\n\
 noisy = mod (randerr (10,n) + code, 2);\n\
-[dec, err] = bchdeco (msg, k, t);\n\
+[dec, err] = bchdeco (noisy, k, t);\n\
 @end example\n\
 \n\
 Valid codes can be found using @code{bchpoly}. In general the codeword\n\
