@@ -21,6 +21,9 @@
 #if !defined (octave_galois_h)
 #define octave_galois_h 1
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <octave/ov.h>
 #include <octave/ov-typeinfo.h>
 
@@ -44,8 +47,12 @@ typedef int octave_hdf5_id;
 #endif
 #endif
 
-class octave_value_list;
-class tree_walker;
+#if ! defined (OV_REP_TYPE)
+#  define OV_REP_TYPE octave_base_value
+#endif
+
+//class octave_value_list;
+//class tree_walker;
 
 // Data structures.
 
@@ -96,7 +103,7 @@ public:
 
   bool is_defined (void) const { return true; }
 
-  bool is_numeric_type (void) const { return true; }
+  bool OV_ISNUMERIC (void) const { return true; }
 
   bool is_constant (void) const { return true; }
 
@@ -120,7 +127,7 @@ public:
 
   bool is_real_matrix (void) const { return false; }
 
-  bool is_real_type (void) const { return false; }
+  bool OV_ISREAL (void) const { return false; }
 
   // FIXME
   bool valid_as_scalar_index (void) const { return false; }
@@ -153,7 +160,7 @@ public:
   bool save_binary (std::ostream& os, bool& save_as_floats);
 
   bool load_binary (std::istream& is, bool swap,
-                    oct_mach_info::float_format fmt);
+                    OCTAVE_MACH_INFO_FLOAT_FORMAT fmt);
 
   bool save_hdf5 (octave_hdf5_id loc_id, const char *name, bool save_as_floats);
 
