@@ -18,6 +18,10 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 #include <string>
 
@@ -216,8 +220,8 @@ the polynomial forms of the primitives. The return value is not affected.\n\
       for (int i = (1<<m)+1; i < (1<<(1+m)); i+=2)
         if (do_isprimitive (i, m))
           {
-            primpolys.resize (primpolys.length ()+1);
-            primpolys(primpolys.length ()-1) = (double)i;
+            primpolys.resize (primpolys.numel ()+1);
+            primpolys(primpolys.numel ()-1) = (double)i;
           }
       break;
     case PRIMPOLY_K:
@@ -231,8 +235,8 @@ the polynomial forms of the primitives. The return value is not affected.\n\
             {
               if (do_isprimitive (i, m))
                 {
-                  primpolys.resize (primpolys.length ()+1);
-                  primpolys(primpolys.length ()-1) = (double)i;
+                  primpolys.resize (primpolys.numel ()+1);
+                  primpolys(primpolys.numel ()-1) = (double)i;
                 }
             }
         }
@@ -244,12 +248,12 @@ the polynomial forms of the primitives. The return value is not affected.\n\
 
   if (disp)
     {
-      if (primpolys.length () == 0)
+      if (primpolys.numel () == 0)
         warning ("primpoly: No primitive polynomial satisfies the given constraints");
       else
         {
           octave_stdout << std::endl << "Primitive polynomial(s) =" << std::endl << std::endl;
-          for (int i = 0; i < primpolys.length (); i++)
+          for (int i = 0; i < primpolys.numel (); i++)
             {
               bool first = true;
               for (int j = m; j >= 0; j--)
